==> static_postgres_orm-0.0.4-dev.tar.gz: test/orm_product_test.dart <==
import 'package:dartz/dartz.dart';
import 'package:test/test.dart';
import '../example/orm_product.dart';
import 'package:static_postgres_orm/static_postgres_orm.dart';

void main() async {
  var _postgresConnection = Postgres_SqlConnection(
      '192.168.1.81', 5432, 'db_teste', 'postgres', '1489');
  _postgresConnection.className = 'tester';

  var product = Product_ORM(_postgresConnection);

  group('Product_ORM', () {
    group('Empty Database', () {
      test('-preparation', () async {
        var value = (await _postgresConnection.executeCommand(
                'delete', 'delete from product'))
            .isRight();
        expect(value, equals(true));
      });

      test('-deleteRecord', () async {
        var value = (await product.deleteRecord(1, 1))
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals('record not found'));
      });

      test('-delete', () async {
        product.company_id.setValue(1);
        product.product_id.setValue(1);
        var value = (await product.delete())
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals('record not found'));
      });

      test('-update', () async {
        product.company_id.setValue(1);
        product.product_id.setValue(1);
        product.description.setValue('value');
        var value = (await product.update())
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals('record not found'));
      });

      test('-materialize', () async {
        var value = (await product.materialize(1, 1))
            .fold((l) => l.errorMessage.first, (r) => r.result);
        expect(value, equals('record not found'));
      });

      test('-insert', () async {
        product.clear();
        product.company_id.setValue(1);
        product.product_id.setValue(1);

        var value =
            (await product.insert()).fold((l) => l.result, (r) => r.result);

        
        expect(value, equals(true));
      });
    });

    group('Database with Two Records', () {
      test('-preparation1', () async {
        var value = (await _postgresConnection.executeCommand(
                'delete', 'delete from product'))
            .isRight();
        expect(value, equals(true));
      });

      test('-preparation2', () async {
        var value = (await _postgresConnection.executeCommand('delete',
                'insert into product(company_id,product_id) values(1,1)'))
            .isRight();
        expect(value, equals(true));
      });

      test('-update Succes', () async {
        product.company_id.setValue(1);
        product.product_id.setValue(1);
        product.description.setValue('teste1');
        var value = (await product.update())
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals(1));
      });

      test('-select', () async {
        
        var value = (await product.select()).isRight();
        
        expect(value, true);
      });

      test('-update Error', () async {
        product.company_id.setValue(3);
        product.product_id.setValue(3);
        product.description.setValue('teste1');
        var value = (await product.update())
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals('record not found'));
      });

      test('-materialize Error', () async {
        var value = (await product.materialize(2, 2))
            .fold((l) => l.errorMessage.first, (r) => r.rowsSelected);
        expect(value, equals('record not found'));
      });

      test('-materialize Succes', () async {
        var value = (await product.materialize(1, 1))
            .fold((l) => l.errorMessage.first, (r) => r.rowsSelected);
        expect(value, equals(1));
      });

      test('-deleteRecord Error', () async {
        var value = (await product.deleteRecord(3, 3))
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals('record not found'));
      });

      test('-deleteRecord Succes', () async {
        var value = (await product.deleteRecord(1, 1))
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals(1));
      });

      test('-insert', () async {
        product.clear();
        product.company_id.setValue(1);
        product.product_id.setValue(1);

        var value =
            (await product.insert()).fold((l) => l.result, (r) => r.result);
        expect(value, equals(true));
      });

      test('-delete Succes', () async {
        var value = (await product.delete())
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals(1));
      });

      test('-delete Error', () async {
        var value = (await product.delete())
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals('O campo company_id é obrigatório'));
      });
    });

    group('Duo', () {
      test('-preparation', () async {
        var value = (await _postgresConnection.executeCommand(
                'delete', 'delete from product'))
            .isRight();
        expect(value, equals(true));
      });

      test('-materialize', () async {
        var x = <bool>[];
        product.company_id.setValue(1);
        product.product_id.setValue(1);
        x.add((await product.insert()).isRight());
        product.clear();
        x.add((await product.materialize(1, 1)).isRight());
        x.add((await product.materialize(1, 1)).isRight());
        var value = product.count;

        expect(value, equals(1));
        expect(x, equals([true, true, true]));
      });

      test('-insert', () async {
        var x = <bool>[];
        product.company_id.setValue(1);
        product.product_id.setValue(2);
        x.add((await product.insert()).isRight());
        x.add((await product.insert()).isRight());
        var value = product.count;

        expect(value, equals(2));
        expect(x, equals([true, false]));
      });

      test('-update', () async {
        var x = <bool>[];
        product.description.setValue('duo teste');
        x.add((await product.update()).isRight());
        product.description.setValue('duo teste');
        x.add((await product.update()).isRight());
        var value = product.count;

        expect(value, equals(2));
        expect(x, equals([true, true]));
      });

      test('-delete', () async {
        var x = <bool>[];

        x.add((await product.delete()).isRight());
        x.add((await product.delete()).isRight());
        x.add((await product.delete()).isRight());
        var value = product.count;

        expect(value, equals(0));
        expect(x, equals([true, true, false]));
      });

      test('-deleteRecord', () async {
        var x = <bool>[];
        product.company_id.setValue(1);
        product.product_id.setValue(1);
        x.add((await product.insert()).isRight());
        product.company_id.setValue(2);
        product.product_id.setValue(2);
        x.add((await product.insert()).isRight());
        var value1 = product.count;
        product.clear();
        x.add((await product.deleteRecord(2, 2)).isRight());
        x.add((await product.deleteRecord(2, 2)).isRight());
        var value2 = product.count;

        expect(value1, equals(2));
        expect(value2, equals(0));
        expect(x, equals([true, true, true, false]));
      });
    });

    group('Handling Changes', () {
      test('-preparation', () async {
        var value = (await _postgresConnection.executeCommand(
                'delete', 'delete from product'))
            .isRight();
        expect(value, equals(true));
      });

      test('-materialize', () async {
        var x = <dynamic>[];
        product.company_id.setValue(1);
        product.product_id.setValue(1);
        x.add((await product.insert()).isRight());
        product.clear();
        x.add((await product.materialize(1, 1)).isRight());
        product.clear();
        x.add((await product.materialize(1, 1)).isRight());
        product.company_id.setValue(1);
        product.product_id.setValue(55);
        x.add(product.count);
        product.cancelChanges();
        x.add(product.count);
        expect(x, equals([true, true, true, 1, 1]));
      });

      test('-update', () async {
        var x = <dynamic>[];
        product.company_id.setValue(1);
        product.product_id.setValue(55);
        x.add((await product.update()).isRight());
        product.cancelChanges();
        x.add((await product.update()).isRight());
        x.add(product.count);
        expect(x, equals([false, true, 1]));
      });

      test('-delete', () async {
        var x = <dynamic>[];
        product.company_id.setValue(1);
        product.product_id.setValue(55);
        x.add((await product.delete()).isRight());
        product.cancelChanges();
        x.add((await product.delete()).isRight());
        x.add(product.count);
        product.company_id.setValue(1);
        product.product_id.setValue(1);
        x.add((await product.insert()).isRight());
        x.add(product.count);
        expect(x, equals([false, true, 0, true, 1]));
      });

      test('-deleteRecord', () async {
        var x = <dynamic>[];
        product.company_id.setValue(1);
        product.product_id.setValue(55);
        x.add((await product.deleteRecord(1, 1)).isRight());
        product.company_id.setValue(1);
        product.product_id.setValue(56);
        x.add((await product.deleteRecord(55, 55)).isRight());
        x.add(product.count);
        expect(x, equals([true, false, 0]));
      });
    });

    test('-update to null', () async {
      var x = <dynamic>[];
      var product = Product_ORM(_postgresConnection);
      await product.deleteRecord(1, 1);
      product.company_id.setValue(1);
      product.product_id.setValue(1);
      product.code.setValue('1651651');
      x.add((await product.insert()).isRight());
      product.clear();
      x.add((await product.materialize(1, 1)).isRight());
      product.code.setNull();
      x.add((await product.update()).isRight());
      product.clear();
      x.add((await product.materialize(1, 1)).isRight());
      x.add(product.code.value.isNone());
      expect(x, equals([true, true, true, true, true]));
    });

    group('GRPC proto3 ', () {
      setUp(() async {
        (await _postgresConnection.executeCommand(
            'delete', 'delete from product'));
      });
      test('-insertFromProto3Json', () async {
        var x = (await product.insertFromProto3Json({
          'companyId': {'value': 1},
          'productId': {'value': 1}
        }));
        expect(x.isRight(), true);
      });

      test('-deleteFromProto3Json', () async {
        product.product_id.setValue(1);
        product.company_id.setValue(1);
        await (product.insert());
        var x = (await product.deleteFromProto3Json({
          'companyId': {'value': 1},
          'productId': {'value': 1}
        }));
        expect(x.isRight(), true);
      });

      test('updateFromProto3Json', () async {
        product.product_id.setValue(1);
        product.company_id.setValue(1);
        await product.insert();
        product.clear();
        (await product.updateFromProto3Json({
          'companyId': {'value': 1},
          'productId': {'value': 1},
          'code': {'value': 'updated'}
        }))
            .leftMap((l) => print(l.toJson()));
        var x = '';

        product.code.value.map((a) => x = a);
        expect(x, 'updated');
        var y = (await product.updateFromProto3Json({
          'companyId': {'value': 1},
          'productId': {'value': 165156165},
          'code': {'value': 'updated'}
        }))
            .isRight();
        expect(y, false);
        expect(product.count, 0);
      });

      test('updateFromProto3Json -invalid', () async {
        product.product_id.setValue(1);
        product.company_id.setValue(1);
        await product.insert();
        product.clear();
        (await product.updateFromProto3Json({
          'companyId': {'value': 1},

        }))
            .leftMap((l) => null);
        var x = '';

        product.code.value.map((a) => x = a);
        expect(x, '');
        
      });
    });
  });

  group('order by', (){
    test('1 record implicit', (){
      var x = OrderBy()..product_id();
      expect(x.toString(), 'ORDER BY product.product_id ASC');
    });

    test('1 record explicit ASC', (){
      var x = OrderBy()..product_id(OrdType.asc);
      expect(x.toString(), 'ORDER BY product.product_id ASC');
    });

    test('1 record explicit DEC', (){
      var x = OrderBy()..product_id(OrdType.desc);
      expect(x.toString(), 'ORDER BY product.product_id DESC');
    });

    test('2 record explicit alternate', (){
      var x = OrderBy()
      ..company_id(OrdType.desc)
      ..product_id(OrdType.asc);
      expect(x.toString(), 
      'ORDER BY product.company_id DESC, product.product_id ASC');
    });
  });


  group('Select with order by', (){
    setUp(() async{
      await _postgresConnection.executeCommand('delete', 'delete from product');
      var orm = Product_ORM(_postgresConnection);
      orm.company_id.setValue(1);
      
      for (var i = 1;i <= 50; i++){
        orm.product_id.setValue(i);
        orm.code.setValue(i.toString());
        await orm.insert();
      }    
    });

    test('order by id', () async{
      var orm = Product_ORM(_postgresConnection);

      var result = (await orm.select(
        orderBy: OrderBy()
        ..product_id(OrdType.desc)
        ..code()
      ));

      var x;

      result.map((r) => r.fieldByName('product_id').map((a) => a.tryGetValue((value) {
        x = value;
        return true;
      })));

      expect(x, 50);


    });

  });
}

==> static_postgres_orm-0.1.0.tar.gz: test/orm_product_test.dart <==
import 'package:test/test.dart';
import '../example/orm_product_example.dart';
import 'package:static_postgres_orm/static_postgres_orm.dart';

void main() async {
  var _postgresConnection = Postgres_SqlConnection(
      '192.168.1.81', 5432, 'db_teste', 'postgres', '1489');
  _postgresConnection.className = 'tester';

  var product = Product_ORM(_postgresConnection);

  group('Product_ORM', () {
    group('Empty Database', () {
      test('-preparation', () async {
        var value = (await _postgresConnection.executeCommand(
                'delete', 'delete from product'))
            .isRight();
        expect(value, equals(true));
      });

      test('-deleteRecord', () async {
        var value = (await product.deleteRecord(1, 1))
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals('record not found'));
      });

      test('-delete', () async {
        product.company_id.setValue(1);
        product.product_id.setValue(1);
        var value = (await product.delete())
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals('record not found'));
      });

      test('-update', () async {
        product.company_id.setValue(1);
        product.product_id.setValue(1);
        product.description.setValue('value');
        var value = (await product.update())
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals('record not found'));
      });

      test('-materialize', () async {
        var value = (await product.materialize(1, 1))
            .fold((l) => l.errorMessage.first, (r) => r.result);
        expect(value, equals('record not found'));
      });

      test('-insert', () async {
        product.clear();
        product.company_id.setValue(1);
        product.product_id.setValue(1);

        var value =
            (await product.insert()).fold((l) => l.result, (r) => r.result);

        expect(value, equals(true));
      });
    });

    group('Database with Two Records', () {
      test('-preparation1', () async {
        var value = (await _postgresConnection.executeCommand(
                'delete', 'delete from product'))
            .isRight();
        expect(value, equals(true));
      });

      test('-preparation2', () async {
        var value = (await _postgresConnection.executeCommand('delete',
                'insert into product(company_id,product_id) values(1,1)'))
            .isRight();
        expect(value, equals(true));
      });

      test('-update Succes', () async {
        product.company_id.setValue(1);
        product.product_id.setValue(1);
        product.description.setValue('teste1');
        var value = (await product.update())
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals(1));
      });

      test('-select', () async {
        var value = (await product.select()).isRight();

        expect(value, true);
      });

      test('-update Error', () async {
        product.company_id.setValue(3);
        product.product_id.setValue(3);
        product.description.setValue('teste1');
        var value = (await product.update())
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals('record not found'));
      });

      test('-materialize Error', () async {
        var value = (await product.materialize(2, 2))
            .fold((l) => l.errorMessage.first, (r) => r.rowsSelected);
        expect(value, equals('record not found'));
      });

      test('-materialize Succes', () async {
        var value = (await product.materialize(1, 1))
            .fold((l) => l.errorMessage.first, (r) => r.rowsSelected);
        expect(value, equals(1));
      });

      test('-deleteRecord Error', () async {
        var value = (await product.deleteRecord(3, 3))
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals('record not found'));
      });

      test('-deleteRecord Succes', () async {
        var value = (await product.deleteRecord(1, 1))
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals(1));
      });

      test('-insert', () async {
        product.clear();
        product.company_id.setValue(1);
        product.product_id.setValue(1);

        var value =
            (await product.insert()).fold((l) => l.result, (r) => r.result);
        expect(value, equals(true));
      });

      test('-delete Succes', () async {
        var value = (await product.delete())
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals(1));
      });

      test('-delete Error', () async {
        var value = (await product.delete())
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals('O campo company_id é obrigatório'));
      });
    });

    group('Duo', () {
      test('-preparation', () async {
        var value = (await _postgresConnection.executeCommand(
                'delete', 'delete from product'))
            .isRight();
        expect(value, equals(true));
      });

      test('-materialize', () async {
        var x = <bool>[];
        product.company_id.setValue(1);
        product.product_id.setValue(1);
        x.add((await product.insert()).isRight());
        product.clear();
        x.add((await product.materialize(1, 1)).isRight());
        x.add((await product.materialize(1, 1)).isRight());
        var value = product.count;

        expect(value, equals(1));
        expect(x, equals([true, true, true]));
      });

      test('-insert', () async {
        var x = <bool>[];
        product.company_id.setValue(1);
        product.product_id.setValue(2);
        x.add((await product.insert()).isRight());
        x.add((await product.insert()).isRight());
        var value = product.count;

        expect(value, equals(2));
        expect(x, equals([true, false]));
      });

      test('-update', () async {
        var x = <bool>[];
        product.description.setValue('duo teste');
        x.add((await product.update()).isRight());
        product.description.setValue('duo teste');
        x.add((await product.update()).isRight());
        var value = product.count;

        expect(value, equals(2));
        expect(x, equals([true, true]));
      });

      test('-delete', () async {
        var x = <bool>[];

        x.add((await product.delete()).isRight());
        x.add((await product.delete()).isRight());
        x.add((await product.delete()).isRight());
        var value = product.count;

        expect(value, equals(0));
        expect(x, equals([true, true, false]));
      });

      test('-deleteRecord', () async {
        var x = <bool>[];
        product.company_id.setValue(1);
        product.product_id.setValue(1);
        x.add((await product.insert()).isRight());
        product.company_id.setValue(2);
        product.product_id.setValue(2);
        x.add((await product.insert()).isRight());
        var value1 = product.count;
        product.clear();
        x.add((await product.deleteRecord(2, 2)).isRight());
        x.add((await product.deleteRecord(2, 2)).isRight());
        var value2 = product.count;

        expect(value1, equals(2));
        expect(value2, equals(0));
        expect(x, equals([true, true, true, false]));
      });
    });

    group('Handling Changes', () {
      test('-preparation', () async {
        var value = (await _postgresConnection.executeCommand(
                'delete', 'delete from product'))
            .isRight();
        expect(value, equals(true));
      });

      test('-materialize', () async {
        var x = <dynamic>[];
        product.company_id.setValue(1);
        product.product_id.setValue(1);
        x.add((await product.insert()).isRight());
        product.clear();
        x.add((await product.materialize(1, 1)).isRight());
        product.clear();
        x.add((await product.materialize(1, 1)).isRight());
        product.company_id.setValue(1);
        product.product_id.setValue(55);
        x.add(product.count);
        product.cancelChanges();
        x.add(product.count);
        expect(x, equals([true, true, true, 1, 1]));
      });

      test('-update', () async {
        var x = <dynamic>[];
        product.company_id.setValue(1);
        product.product_id.setValue(55);
        x.add((await product.update()).isRight());
        product.cancelChanges();
        x.add((await product.update()).isRight());
        x.add(product.count);
        expect(x, equals([false, true, 1]));
      });

      test('-delete', () async {
        var x = <dynamic>[];
        product.company_id.setValue(1);
        product.product_id.setValue(55);
        x.add((await product.delete()).isRight());
        product.cancelChanges();
        x.add((await product.delete()).isRight());
        x.add(product.count);
        product.company_id.setValue(1);
        product.product_id.setValue(1);
        x.add((await product.insert()).isRight());
        x.add(product.count);
        expect(x, equals([false, true, 0, true, 1]));
      });

      test('-deleteRecord', () async {
        var x = <dynamic>[];
        product.company_id.setValue(1);
        product.product_id.setValue(55);
        x.add((await product.deleteRecord(1, 1)).isRight());
        product.company_id.setValue(1);
        product.product_id.setValue(56);
        x.add((await product.deleteRecord(55, 55)).isRight());
        x.add(product.count);
        expect(x, equals([true, false, 0]));
      });
    });

    test('-update to null', () async {
      var x = <dynamic>[];
      var product = Product_ORM(_postgresConnection);
      await product.deleteRecord(1, 1);
      product.company_id.setValue(1);
      product.product_id.setValue(1);
      product.code.setValue('1651651');
      x.add((await product.insert()).isRight());
      product.clear();
      x.add((await product.materialize(1, 1)).isRight());
      product.code.setNull();
      x.add((await product.update()).isRight());
      product.clear();
      x.add((await product.materialize(1, 1)).isRight());
      x.add(product.code.value.isNone());
      expect(x, equals([true, true, true, true, true]));
    });

    group('GRPC proto3 ', () {
      setUp(() async {
        (await _postgresConnection.executeCommand(
            'delete', 'delete from product'));
      });
      test('-insertFromProto3Json', () async {
        var x = (await product.insertFromProto3Json({
          'companyId': {'value': 1},
          'productId': {'value': 1}
        }));
        expect(x.isRight(), true);
      });

      test('-deleteFromProto3Json', () async {
        product.product_id.setValue(1);
        product.company_id.setValue(1);
        await (product.insert());
        var x = (await product.deleteFromProto3Json({
          'companyId': {'value': 1},
          'productId': {'value': 1}
        }));
        expect(x.isRight(), true);
      });

      test('updateFromProto3Json', () async {
        product.product_id.setValue(1);
        product.company_id.setValue(1);
        await product.insert();
        product.clear();
        (await product.updateFromProto3Json({
          'companyId': {'value': 1},
          'productId': {'value': 1},
          'code': {'value': 'updated'}
        }))
            .leftMap((l) => print(l.toJson()));
        var x = '';

        product.code.value.map((a) => x = a);
        expect(x, 'updated');
        var y = (await product.updateFromProto3Json({
          'companyId': {'value': 1},
          'productId': {'value': 165156165},
          'code': {'value': 'updated'}
        }))
            .isRight();
        expect(y, false);
        expect(product.count, 0);
      });

      test('updateFromProto3Json -invalid', () async {
        product.product_id.setValue(1);
        product.company_id.setValue(1);
        await product.insert();
        product.clear();
        (await product.updateFromProto3Json({
          'companyId': {'value': 1},
        }))
            .leftMap((l) => null);
        var x = '';

        product.code.value.map((a) => x = a);
        expect(x, '');
      });
    });
  });

  group('order by', () {
    test('1 record implicit', () {
      var x = OrderBy()..product_id();
      expect(x.toString(), 'ORDER BY product.product_id ASC');
    });

    test('1 record explicit ASC', () {
      var x = OrderBy()..product_id(OrdType.asc);
      expect(x.toString(), 'ORDER BY product.product_id ASC');
    });

    test('1 record explicit DEC', () {
      var x = OrderBy()..product_id(OrdType.desc);
      expect(x.toString(), 'ORDER BY product.product_id DESC');
    });

    test('2 record explicit alternate', () {
      var x = OrderBy()
        ..company_id(OrdType.desc)
        ..product_id(OrdType.asc);
      expect(x.toString(),
          'ORDER BY product.company_id DESC, product.product_id ASC');
    });
  });

  group('Select with order by', () {
    setUp(() async {
      await _postgresConnection.executeCommand('delete', 'delete from product');
      var orm = Product_ORM(_postgresConnection);
      orm.company_id.setValue(1);

      for (var i = 1; i <= 50; i++) {
        orm.product_id.setValue(i);
        orm.code.setValue(i.toString());
        await orm.insert();
      }
    });

    test('order by id', () async {
      var orm = Product_ORM(_postgresConnection);

      var result = (await orm.select(
          orderBy: OrderBy()
            ..product_id(OrdType.desc)
            ..code()));

      var x;

      result.map(
          (r) => r.fieldByName('product_id').map((a) => a.tryGetValue((value) {
                x = value;
                return true;
              })));

      expect(x, 50);
    });
  });
}
